==> dtk6declarative-debug-6.0.30-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/qrc_dtkdeclarative_overridable_qml.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.9.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // InWindowBlur.qml
  0x0,0x0,0x3,0xaa,
  0x2f,
  0x2f,0x20,0x53,0x50,0x44,0x58,0x2d,0x46,0x69,0x6c,0x65,0x43,0x6f,0x70,0x79,0x72,
  0x69,0x67,0x68,0x74,0x54,0x65,0x78,0x74,0x3a,0x20,0x32,0x30,0x32,0x33,0x20,0x55,
  0x6e,0x69,0x6f,0x6e,0x54,0x65,0x63,0x68,0x20,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,
  0x65,0x20,0x54,0x65,0x63,0x68,0x6e,0x6f,0x6c,0x6f,0x67,0x79,0x20,0x43,0x6f,0x2e,
  0x2c,0x20,0x4c,0x74,0x64,0x2e,0xa,0x2f,0x2f,0xa,0x2f,0x2f,0x20,0x53,0x50,0x44,
  0x58,0x2d,0x4c,0x69,0x63,0x65,0x6e,0x73,0x65,0x2d,0x49,0x64,0x65,0x6e,0x74,0x69,
  0x66,0x69,0x65,0x72,0x3a,0x20,0x4c,0x47,0x50,0x4c,0x2d,0x33,0x2e,0x30,0x2d,0x6f,
  0x72,0x2d,0x6c,0x61,0x74,0x65,0x72,0xa,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,
  0x51,0x74,0x51,0x75,0x69,0x63,0x6b,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,
  0x74,0x51,0x75,0x69,0x63,0x6b,0x2e,0x45,0x66,0x66,0x65,0x63,0x74,0x73,0xa,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x74,0x6b,0x20,0x31,0x2e,0x30,0x20,0x61,0x73,0x20,0x44,0xa,0xa,0x49,
  0x74,0x65,0x6d,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x69,0x64,0x20,0x3a,0x63,0x6f,
  0x6e,0x74,0x72,0x6f,0x6c,0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,
  0x74,0x79,0x20,0x62,0x6f,0x6f,0x6c,0x20,0x6f,0x66,0x66,0x73,0x63,0x72,0x65,0x65,
  0x6e,0x3a,0x20,0x66,0x61,0x6c,0x73,0x65,0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,
  0x70,0x65,0x72,0x74,0x79,0x20,0x61,0x6c,0x69,0x61,0x73,0x20,0x72,0x61,0x64,0x69,
  0x75,0x73,0x3a,0x20,0x62,0x6c,0x75,0x72,0x2e,0x62,0x6c,0x75,0x72,0x4d,0x61,0x78,
  0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x20,0x61,0x6c,
  0x69,0x61,0x73,0x20,0x6d,0x75,0x6c,0x74,0x69,0x70,0x6c,0x69,0x65,0x72,0x3a,0x20,
  0x62,0x6c,0x75,0x72,0x2e,0x62,0x6c,0x75,0x72,0x4d,0x75,0x6c,0x74,0x69,0x70,0x6c,
  0x69,0x65,0x72,0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,
  0x20,0x61,0x6c,0x69,0x61,0x73,0x20,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x3a,0x20,
  0x62,0x6c,0x75,0x72,0xa,0x20,0x20,0x20,0x20,0x64,0x65,0x66,0x61,0x75,0x6c,0x74,
  0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x20,0x61,0x6c,0x69,0x61,0x73,0x20,
  0x64,0x61,0x74,0x61,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0x2e,0x64,0x61,
  0x74,0x61,0xa,0x20,0x20,0x20,0x20,0x72,0x65,0x61,0x64,0x6f,0x6e,0x6c,0x79,0x20,
  0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x20,0x62,0x6f,0x6f,0x6c,0x20,0x76,0x61,
  0x6c,0x69,0x64,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0x2e,0x62,0x6c,0x69,
  0x74,0x74,0x65,0x72,0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0xa,0xa,0x20,0x20,0x20,
  0x20,0x44,0x2e,0x42,0x61,0x63,0x6b,0x64,0x72,0x6f,0x70,0x42,0x6c,0x69,0x74,0x74,
  0x65,0x72,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,0x64,0x3a,
  0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x61,0x6e,0x63,0x68,0x6f,0x72,0x73,0x2e,0x66,0x69,0x6c,0x6c,0x3a,0x20,0x70,
  0x61,0x72,0x65,0x6e,0x74,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,0x6c,
  0x69,0x74,0x74,0x65,0x72,0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0x3a,0x20,0x21,0x44,
  0x2e,0x44,0x54,0x4b,0x2e,0x69,0x73,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,0x52,
  0x65,0x6e,0x64,0x65,0x72,0xa,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x4d,
  0x75,0x6c,0x74,0x69,0x45,0x66,0x66,0x65,0x63,0x74,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,0x64,0x3a,0x20,0x62,0x6c,0x75,
  0x72,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x76,0x69,
  0x73,0x69,0x62,0x6c,0x65,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0x2e,0x62,
  0x6c,0x69,0x74,0x74,0x65,0x72,0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0x20,0x26,0x26,
  0x20,0x21,0x63,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x2e,0x6f,0x66,0x66,0x73,0x63,0x72,
  0x65,0x65,0x6e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x61,0x6e,0x63,0x68,0x6f,0x72,0x73,0x2e,0x66,0x69,0x6c,0x6c,0x3a,0x20,0x70,0x61,
  0x72,0x65,0x6e,0x74,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x73,0x6f,0x75,0x72,0x63,0x65,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,
  0x2e,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x61,0x75,0x74,0x6f,0x50,0x61,0x64,0x64,0x69,0x6e,0x67,
  0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0x3a,0x20,0x66,0x61,0x6c,0x73,0x65,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,0x6c,0x75,0x72,0x45,
  0x6e,0x61,0x62,0x6c,0x65,0x64,0x3a,0x20,0x74,0x72,0x75,0x65,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,0x6c,0x75,0x72,0x3a,0x20,0x31,
  0x2e,0x30,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,
  0x6c,0x75,0x72,0x4d,0x61,0x78,0x3a,0x20,0x36,0x34,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x61,0x74,0x75,0x72,0x61,0x74,0x69,0x6f,
  0x6e,0x3a,0x20,0x30,0x2e,0x34,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,
  0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // declarative
  0x0,0xb,
  0x8,0x5d,0xc4,0x85,
  0x0,0x64,
  0x0,0x65,0x0,0x63,0x0,0x6c,0x0,0x61,0x0,0x72,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x76,0x0,0x65,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // overridable
  0x0,0xb,
  0x8,0x17,0xe0,0x5,
  0x0,0x6f,
  0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x72,0x0,0x69,0x0,0x64,0x0,0x61,0x0,0x62,0x0,0x6c,0x0,0x65,
    // InWindowBlur.qml
  0x0,0x10,
  0x3,0x47,0x90,0x9c,
  0x0,0x49,
  0x0,0x6e,0x0,0x57,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x42,0x0,0x6c,0x0,0x75,0x0,0x72,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/dtk
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/dtk/declarative
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/dtk/declarative/qml
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/dtk/declarative/qml/overridable
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/dtk/declarative/qml/overridable/InWindowBlur.qml
  0x0,0x0,0x0,0x50,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_overridable_qml)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_overridable_qml)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_overridable_qml)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_overridable_qml)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_overridable_qml)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_overridable_qml)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> dtk6declarative-debug-6.0.31-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/qrc_dtkdeclarative_overridable_qml.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.9.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // InWindowBlur.qml
  0x0,0x0,0x3,0xaa,
  0x2f,
  0x2f,0x20,0x53,0x50,0x44,0x58,0x2d,0x46,0x69,0x6c,0x65,0x43,0x6f,0x70,0x79,0x72,
  0x69,0x67,0x68,0x74,0x54,0x65,0x78,0x74,0x3a,0x20,0x32,0x30,0x32,0x33,0x20,0x55,
  0x6e,0x69,0x6f,0x6e,0x54,0x65,0x63,0x68,0x20,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,
  0x65,0x20,0x54,0x65,0x63,0x68,0x6e,0x6f,0x6c,0x6f,0x67,0x79,0x20,0x43,0x6f,0x2e,
  0x2c,0x20,0x4c,0x74,0x64,0x2e,0xa,0x2f,0x2f,0xa,0x2f,0x2f,0x20,0x53,0x50,0x44,
  0x58,0x2d,0x4c,0x69,0x63,0x65,0x6e,0x73,0x65,0x2d,0x49,0x64,0x65,0x6e,0x74,0x69,
  0x66,0x69,0x65,0x72,0x3a,0x20,0x4c,0x47,0x50,0x4c,0x2d,0x33,0x2e,0x30,0x2d,0x6f,
  0x72,0x2d,0x6c,0x61,0x74,0x65,0x72,0xa,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,
  0x51,0x74,0x51,0x75,0x69,0x63,0x6b,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,
  0x74,0x51,0x75,0x69,0x63,0x6b,0x2e,0x45,0x66,0x66,0x65,0x63,0x74,0x73,0xa,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x74,0x6b,0x20,0x31,0x2e,0x30,0x20,0x61,0x73,0x20,0x44,0xa,0xa,0x49,
  0x74,0x65,0x6d,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x69,0x64,0x20,0x3a,0x63,0x6f,
  0x6e,0x74,0x72,0x6f,0x6c,0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,
  0x74,0x79,0x20,0x62,0x6f,0x6f,0x6c,0x20,0x6f,0x66,0x66,0x73,0x63,0x72,0x65,0x65,
  0x6e,0x3a,0x20,0x66,0x61,0x6c,0x73,0x65,0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,
  0x70,0x65,0x72,0x74,0x79,0x20,0x61,0x6c,0x69,0x61,0x73,0x20,0x72,0x61,0x64,0x69,
  0x75,0x73,0x3a,0x20,0x62,0x6c,0x75,0x72,0x2e,0x62,0x6c,0x75,0x72,0x4d,0x61,0x78,
  0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x20,0x61,0x6c,
  0x69,0x61,0x73,0x20,0x6d,0x75,0x6c,0x74,0x69,0x70,0x6c,0x69,0x65,0x72,0x3a,0x20,
  0x62,0x6c,0x75,0x72,0x2e,0x62,0x6c,0x75,0x72,0x4d,0x75,0x6c,0x74,0x69,0x70,0x6c,
  0x69,0x65,0x72,0xa,0x20,0x20,0x20,0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,
  0x20,0x61,0x6c,0x69,0x61,0x73,0x20,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x3a,0x20,
  0x62,0x6c,0x75,0x72,0xa,0x20,0x20,0x20,0x20,0x64,0x65,0x66,0x61,0x75,0x6c,0x74,
  0x20,0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x20,0x61,0x6c,0x69,0x61,0x73,0x20,
  0x64,0x61,0x74,0x61,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0x2e,0x64,0x61,
  0x74,0x61,0xa,0x20,0x20,0x20,0x20,0x72,0x65,0x61,0x64,0x6f,0x6e,0x6c,0x79,0x20,
  0x70,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x20,0x62,0x6f,0x6f,0x6c,0x20,0x76,0x61,
  0x6c,0x69,0x64,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0x2e,0x62,0x6c,0x69,
  0x74,0x74,0x65,0x72,0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0xa,0xa,0x20,0x20,0x20,
  0x20,0x44,0x2e,0x42,0x61,0x63,0x6b,0x64,0x72,0x6f,0x70,0x42,0x6c,0x69,0x74,0x74,
  0x65,0x72,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,0x64,0x3a,
  0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x61,0x6e,0x63,0x68,0x6f,0x72,0x73,0x2e,0x66,0x69,0x6c,0x6c,0x3a,0x20,0x70,
  0x61,0x72,0x65,0x6e,0x74,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,0x6c,
  0x69,0x74,0x74,0x65,0x72,0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0x3a,0x20,0x21,0x44,
  0x2e,0x44,0x54,0x4b,0x2e,0x69,0x73,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,0x52,
  0x65,0x6e,0x64,0x65,0x72,0xa,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x4d,
  0x75,0x6c,0x74,0x69,0x45,0x66,0x66,0x65,0x63,0x74,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,0x64,0x3a,0x20,0x62,0x6c,0x75,
  0x72,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x76,0x69,
  0x73,0x69,0x62,0x6c,0x65,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,0x2e,0x62,
  0x6c,0x69,0x74,0x74,0x65,0x72,0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0x20,0x26,0x26,
  0x20,0x21,0x63,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x2e,0x6f,0x66,0x66,0x73,0x63,0x72,
  0x65,0x65,0x6e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x61,0x6e,0x63,0x68,0x6f,0x72,0x73,0x2e,0x66,0x69,0x6c,0x6c,0x3a,0x20,0x70,0x61,
  0x72,0x65,0x6e,0x74,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x73,0x6f,0x75,0x72,0x63,0x65,0x3a,0x20,0x62,0x6c,0x69,0x74,0x74,0x65,0x72,
  0x2e,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x61,0x75,0x74,0x6f,0x50,0x61,0x64,0x64,0x69,0x6e,0x67,
  0x45,0x6e,0x61,0x62,0x6c,0x65,0x64,0x3a,0x20,0x66,0x61,0x6c,0x73,0x65,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,0x6c,0x75,0x72,0x45,
  0x6e,0x61,0x62,0x6c,0x65,0x64,0x3a,0x20,0x74,0x72,0x75,0x65,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,0x6c,0x75,0x72,0x3a,0x20,0x31,
  0x2e,0x30,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x62,
  0x6c,0x75,0x72,0x4d,0x61,0x78,0x3a,0x20,0x36,0x34,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x61,0x74,0x75,0x72,0x61,0x74,0x69,0x6f,
  0x6e,0x3a,0x20,0x30,0x2e,0x34,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,
  0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // declarative
  0x0,0xb,
  0x8,0x5d,0xc4,0x85,
  0x0,0x64,
  0x0,0x65,0x0,0x63,0x0,0x6c,0x0,0x61,0x0,0x72,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x76,0x0,0x65,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // overridable
  0x0,0xb,
  0x8,0x17,0xe0,0x5,
  0x0,0x6f,
  0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x72,0x0,0x69,0x0,0x64,0x0,0x61,0x0,0x62,0x0,0x6c,0x0,0x65,
    // InWindowBlur.qml
  0x0,0x10,
  0x3,0x47,0x90,0x9c,
  0x0,0x49,
  0x0,0x6e,0x0,0x57,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x42,0x0,0x6c,0x0,0x75,0x0,0x72,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x96,0xb9,0x8,0xd1,0x48,
  // :/dtk
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x96,0xb9,0x8,0xd1,0x48,
  // :/dtk/declarative
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x96,0xb9,0x8,0xd1,0x48,
  // :/dtk/declarative/qml
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x96,0xb9,0x8,0xd1,0x48,
  // :/dtk/declarative/qml/overridable
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x96,0xb9,0x8,0xd1,0x48,
  // :/dtk/declarative/qml/overridable/InWindowBlur.qml
  0x0,0x0,0x0,0x50,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x96,0xb9,0x8,0xd1,0x48,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_overridable_qml)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_overridable_qml)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_overridable_qml)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_overridable_qml)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_dtkdeclarative_overridable_qml)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dtkdeclarative_overridable_qml)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
